glenn 01/07/07 13:42:35
Modified: datetime/src/org/apache/taglibs/datetime AmPmsTEI.java
AmPmsTag.java CurrentTimeTag.java FormatTag.java
ParseTag.java TimeZoneTag.java TimeZonesTEI.java
TimeZonesTag.java
Log:
Switch to new build, cleanup
Revision Changes Path
1.3 +5 -5
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTEI.java
Index: AmPmsTEI.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTEI.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- AmPmsTEI.java 2000/11/06 01:16:54 1.2
+++ AmPmsTEI.java 2001/07/07 20:42:27 1.3
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTEI.java,v 1.2
2000/11/06 01:16:54 glenn Exp $
- * $Revision: 1.2 $
- * $Date: 2000/11/06 01:16:54 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTEI.java,v 1.3
2001/07/07 20:42:27 glenn Exp $
+ * $Revision: 1.3 $
+ * $Date: 2001/07/07 20:42:27 $
*
* ====================================================================
*
@@ -65,8 +65,8 @@
import org.apache.taglibs.datetime.*;
/**
- * TagExtraInfo for <b>ampms</b> tag, allows use of standard
- * <jsp:getProperty/> with the <b>ampms</b> tag script
+ * TagExtraInfo for <b>amPms</b> tag, allows use of standard
+ * <jsp:getProperty/> with the <b>amPms</b> tag script
* variable id.
*
* @see AmPmsTag
1.3 +21 -21
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTag.java
Index: CurrentTimeTag.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/CurrentTimeTag.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- CurrentTimeTag.java 2000/11/06 01:18:35 1.2
+++ CurrentTimeTag.java 2001/07/07 20:42:28 1.3
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/CurrentTimeTag.java,v
1.2 2000/11/06 01:18:35 glenn Exp $
- * $Revision: 1.2 $
- * $Date: 2000/11/06 01:18:35 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/CurrentTimeTag.java,v
1.3 2001/07/07 20:42:28 glenn Exp $
+ * $Revision: 1.3 $
+ * $Date: 2001/07/07 20:42:28 $
*
* ====================================================================
*
@@ -68,12 +68,12 @@
import javax.servlet.jsp.tagext.*;
/**
- * JSP Tag <b>currentime</b>, used to get the current time in
+ * JSP Tag <b>currentTime</b>, used to get the current time in
* milliseconds since Jan 1, 1970 GMT.
* <p>
* JSP Tag Lib Descriptor
* <p><pre>
- * <name>currentime</name>
+ * <name>currentTime</name>
* <tagclass>org.apache.taglibs.datetime.CurrentTimeTag</tagclass>
* <bodycontent>empty</bodycontent>
* <info>Gets the current time in milliseconds since Jan 1, 1970
GMT.</info>
1.5 +16 -16
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/FormatTag.java
Index: FormatTag.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/FormatTag.java,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- FormatTag.java 2001/04/26 02:47:28 1.4
+++ FormatTag.java 2001/07/07 20:42:29 1.5
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/FormatTag.java,v
1.4 2001/04/26 02:47:28 glenn Exp $
- * $Revision: 1.4 $
- * $Date: 2001/04/26 02:47:28 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/FormatTag.java,v
1.5 2001/07/07 20:42:29 glenn Exp $
+ * $Revision: 1.5 $
+ * $Date: 2001/07/07 20:42:29 $
*
* ====================================================================
*
@@ -76,9 +76,9 @@
* Uses the optional attribute <b>pattern</b> as the time pattern
* string to use when formatting the Date.
* <p>
- * The optional attribute <b>timezone</b> can be set to the id of
- * a timezone script varaible so that the Date if adjusted for
- * that timezone.
+ * The optional attribute <b>timeZone</b> can be set to the id of
+ * a timeZone script varaible so that the Date if adjusted for
+ * that timeZone.
* <p>
* If the optional attribute <b>locale</b> is true, the Date
* is formatted for the clients locale if known.
@@ -104,7 +104,7 @@
* <rtexprvalue>false</rtexprvalue>
* </attribute>
* <attribute>
- * <name>timezone</name>
+ * <name>timeZone</name>
* <required>false</required>
* <rtexprvalue>false</rtexprvalue>
* </attribute>
@@ -135,8 +135,8 @@
private Locale locale = null;
// Optional attribute, time pattern string to use when formatting date
private String pattern = null;
- // Optional attribute, timezone script variable id to use when formatting date
- private TimeZone timezone = null;
+ // Optional attribute, timeZone script variable id to use when formatting date
+ private TimeZone timeZone = null;
// The date after being formatted for output
private String date_formatted = null;
// The raw date given from the tag
@@ -196,9 +196,9 @@
else
sdf = new SimpleDateFormat(pattern,locale);
- // See if there is a timezone
- if( timezone != null )
- sdf.setTimeZone(timezone);
+ // See if there is a timeZone
+ if( timeZone != null )
+ sdf.setTimeZone(timeZone);
// Format the date for display
date_formatted = sdf.format(date);
@@ -236,14 +236,14 @@
/**
* Set the time zone to use when formatting date.
*
- * Value must be the name of a <b>timezone</b> tag script
+ * Value must be the name of a <b>timeZone</b> tag script
* variable ID.
*
- * @param String name of timezone to use
+ * @param String name of timeZone to use
*/
- public final void setTimezone(String tz)
+ public final void setTimeZone(String tz)
{
- timezone =
+ timeZone =
(TimeZone)pageContext.getAttribute(tz,PageContext.SESSION_SCOPE);
}
1.3 +16 -16
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/ParseTag.java
Index: ParseTag.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/ParseTag.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- ParseTag.java 2000/11/06 01:19:30 1.2
+++ ParseTag.java 2001/07/07 20:42:29 1.3
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/ParseTag.java,v 1.2
2000/11/06 01:19:30 glenn Exp $
- * $Revision: 1.2 $
- * $Date: 2000/11/06 01:19:30 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/ParseTag.java,v 1.3
2001/07/07 20:42:29 glenn Exp $
+ * $Revision: 1.3 $
+ * $Date: 2001/07/07 20:42:29 $
*
* ====================================================================
*
@@ -77,9 +77,9 @@
* Uses the optional attribute <b>pattern</b> as the pattern
* to use when parsing the Date string.
* <p>
- * The optional attribute <b>timezone</b> can be set to the id of
- * a timezone script varaible so that the Date if adjusted for
- * that timezone.
+ * The optional attribute <b>timeZone</b> can be set to the id of
+ * a timeZone script varaible so that the Date if adjusted for
+ * that timeZone.
* <p>
* If the optional attribute <b>locale</b> is true, the Date
* is parsed for the clients locale if known.
@@ -98,7 +98,7 @@
* <rtexprvalue>false</rtexprvalue>
* </attribute>
* <attribute>
- * <name>timezone</name>
+ * <name>timeZone</name>
* <sessuired>false</sessuired>
* <rtexprvalue>false</rtexprvalue>
* </attribute>
@@ -118,8 +118,8 @@
private Locale locale = null;
// Optional attribute, time pattern string to use when formatting date
private String pattern = null;
- // Optional attribute, timezone script variable id to use when formatting date
- private TimeZone timezone = null;
+ // Optional attribute, timeZone script variable id to use when formatting date
+ private TimeZone timeZone = null;
// Date after parsing tag body
private Date date = null;
@@ -158,9 +158,9 @@
else
sdf = new SimpleDateFormat(pattern,locale);
- // See if there is a timezone
- if( timezone != null )
- sdf.setTimeZone(timezone);
+ // See if there is a timeZone
+ if( timeZone != null )
+ sdf.setTimeZone(timeZone);
// Parse the string and create the date.
try {
@@ -204,14 +204,14 @@
/**
* Set the time zone to use when parsing date.
*
- * Value must be the name of a <b>timezone</b> tag script
+ * Value must be the name of a <b>timeZone</b> tag script
* variable ID.
*
- * @param String name of timezone to use
+ * @param String name of timeZone to use
*/
- public final void setTimezone(String tz)
+ public final void setTimeZone(String tz)
{
- timezone =
+ timeZone =
(TimeZone)pageContext.getAttribute(tz,PageContext.SESSION_SCOPE);
}
1.6 +9 -9
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZoneTag.java
Index: TimeZoneTag.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZoneTag.java,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -r1.5 -r1.6
--- TimeZoneTag.java 2000/12/11 01:44:52 1.5
+++ TimeZoneTag.java 2001/07/07 20:42:30 1.6
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZoneTag.java,v
1.5 2000/12/11 01:44:52 glenn Exp $
- * $Revision: 1.5 $
- * $Date: 2000/12/11 01:44:52 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZoneTag.java,v
1.6 2001/07/07 20:42:30 glenn Exp $
+ * $Revision: 1.6 $
+ * $Date: 2001/07/07 20:42:30 $
*
* ====================================================================
*
@@ -54,7 +54,7 @@
*
* This software consists of voluntary contributions made by many
* individuals on behalf of the Apache Software Foundation. For more
- * intimezoneion on the Apache Software Foundation, please see
+ * intimeZoneion on the Apache Software Foundation, please see
* <http://www.apache.org/>.
*
*/
@@ -69,15 +69,15 @@
import javax.servlet.jsp.tagext.*;
/**
- * JSP Tag <b>timezone</b>, used to set the client timezone for
+ * JSP Tag <b>timeZone</b>, used to set the client timeZone for
* the SESSION as a script variable.
* <p>
* The TimeZone ID String is obtained from the body of the tag.
- * If there is no TimeZone ID String, the server default timezone is used.
+ * If there is no TimeZone ID String, the server default timeZone is used.
* <p>
* JSP Tag Lib Descriptor
* <p><pre>
- * <name>timezone</name>
+ * <name>timeZone</name>
* <tagclass>org.apache.taglibs.datetime.TimeZoneTag</tagclass>
* <bodycontent>JSP</bodycontent>
* <info>Creates a SESSION script variable for clients time zone.</info>
@@ -105,7 +105,7 @@
}
/**
- * Method called at end of timezone tag body.
+ * Method called at end of timeZone tag body.
*
* @return SKIP_BODY
*/
@@ -114,7 +114,7 @@
// Use the body of the tag as input for the date
BodyContent body = getBodyContent();
String s = body.getString();
- // Clear the body since we only use it to set the timezone
+ // Clear the body since we only use it to set the timeZone
body.clearBody();
TimeZone tz = TimeZone.getTimeZone(s);
1.3 +5 -5
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTEI.java
Index: TimeZonesTEI.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTEI.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- TimeZonesTEI.java 2000/11/06 01:19:54 1.2
+++ TimeZonesTEI.java 2001/07/07 20:42:30 1.3
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTEI.java,v
1.2 2000/11/06 01:19:54 glenn Exp $
- * $Revision: 1.2 $
- * $Date: 2000/11/06 01:19:54 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTEI.java,v
1.3 2001/07/07 20:42:30 glenn Exp $
+ * $Revision: 1.3 $
+ * $Date: 2001/07/07 20:42:30 $
*
* ====================================================================
*
@@ -65,8 +65,8 @@
import org.apache.taglibs.datetime.*;
/**
- * TagExtraInfo for <b>timezones</b> tag, allows use of standard
- * <jsp:getProperty/> with the <b>timezones</b> tag script
+ * TagExtraInfo for <b>timeZones</b> tag, allows use of standard
+ * <jsp:getProperty/> with the <b>timeZones</b> tag script
* variable id.
*
* @see TimeZonesTag
1.3 +28 -28
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTag.java
Index: AmPmsTag.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTag.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- AmPmsTag.java 2000/11/06 01:17:21 1.2
+++ AmPmsTag.java 2001/07/07 20:42:27 1.3
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTag.java,v 1.2
2000/11/06 01:17:21 glenn Exp $
- * $Revision: 1.2 $
- * $Date: 2000/11/06 01:17:21 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/AmPmsTag.java,v 1.3
2001/07/07 20:42:27 glenn Exp $
+ * $Revision: 1.3 $
+ * $Date: 2001/07/07 20:42:27 $
*
* ====================================================================
*
@@ -69,12 +69,12 @@
import javax.servlet.jsp.tagext.*;
/**
* JSP Tag <b>ampms</b>, used to loop through all the am/pm strings
* so that they can be accessed by using the standard
* JSP <jsp:getProperty> tag.
* <p>
* The script variable of name <b>id</b> is availble only within the
* body of the <b>ampms</b> tag.
* <p>
* Loops through all the am/pm strings.
* <p>
@@ -83,7 +83,7 @@
* <p>
* JSP Tag Lib Descriptor
* <p><pre>
- * <name>ampms</name>
+ * <name>amPms</name>
* <tagclass>org.apache.taglibs.datetime.AmPmsTag</tagclass>
* <teiclass>org.apache.taglibs.datetime.AmPmsTEI</teiclass>
* <bodycontent>JSP</bodycontent>
@@ -106,11 +106,11 @@
public class AmPmsTag extends BodyTagSupport
{
private Locale locale = null;
- private String [] ampms = null;
+ private String [] amPms = null;
private int count = 0;
/**
* Initializes tag so it can loop through the ampms of the year.
*
* @return EVAL_BODY_TAG
*/
@@ -125,12 +125,12 @@
sdf = new SimpleDateFormat(pattern,locale);
DateFormatSymbols dfs = sdf.getDateFormatSymbols();
- ampms = dfs.getAmPmStrings();
+ amPms = dfs.getAmPmStrings();
// Make sure we skip any blank array elements
- while( count < ampms.length &&
- (ampms[count] == null || ampms[count].length() == 0) )
+ while( count < amPms.length &&
+ (amPms[count] == null || amPms[count].length() == 0) )
count++;
- if( count >= ampms.length )
+ if( count >= amPms.length )
return SKIP_BODY;
pageContext.setAttribute(id,this,PageContext.PAGE_SCOPE);
@@ -138,22 +138,22 @@
}
/**
* Method called at end of each ampms tag.
*
- * @return EVAL_BODY_TAG if there is another name, or SKIP_BODY if there are no
more ampms
+ * @return EVAL_BODY_TAG if there is another name, or SKIP_BODY if there are no
more amPms
*/
public final int doAfterBody() throws JspException
{
// See if we are done looping through ampms
count++;
- if( count >= ampms.length )
+ if( count >= amPms.length )
return SKIP_BODY;
// Make sure we skip any blank array elements
- while( count < ampms.length &&
- (ampms[count] == null || ampms[count].length() == 0) )
+ while( count < amPms.length &&
+ (amPms[count] == null || amPms[count].length() == 0) )
count++;
- if( count >= ampms.length )
+ if( count >= amPms.length )
return SKIP_BODY;
// There is another am/pm, so loop again
@@ -198,11 +198,11 @@
*/
public final String getName()
{
- return ampms[count];
+ return amPms[count];
}
/**
* Remove the script variable after ampms tag closed out
*/
public final void release()
{
@@ -69,12 +69,12 @@
import javax.servlet.jsp.tagext.*;
/**
- * JSP Tag <b>ampms</b>, used to loop through all the am/pm strings
+ * JSP Tag <b>amPms</b>, used to loop through all the am/pm strings
* so that they can be accessed by using the standard
* JSP <jsp:getProperty> tag.
@@ -69,12 +69,12 @@
* <p>
* The script variable of name <b>id</b> is availble only within the
- * body of the <b>ampms</b> tag.
+ * body of the <b>amPms</b> tag.
* <p>
* Loops through all the am/pm strings.
@@ -106,11 +106,11 @@
private int count = 0;
/**
- * Initializes tag so it can loop through the ampms of the year.
+ * Initializes tag so it can loop through the amPms of the year.
*
* @return EVAL_BODY_TAG
@@ -138,22 +138,22 @@
}
/**
- * Method called at end of each ampms tag.
+ * Method called at end of each amPms tag.
*
@@ -138,22 +138,22 @@
public final int doAfterBody() throws JspException
{
- // See if we are done looping through ampms
+ // See if we are done looping through amPms
count++;
@@ -198,11 +198,11 @@
}
/**
- * Remove the script variable after ampms tag closed out
+ * Remove the script variable after amPms tag closed out
*/
public final void release()
1.3 +5 -5
jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/CurrentTimeTag.java
Index: TimeZonesTag.java
===================================================================
RCS file:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTag.java,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- TimeZonesTag.java 2000/11/06 01:20:00 1.2
+++ TimeZonesTag.java 2001/07/07 20:42:31 1.3
@@ -1,7 +1,7 @@
/*
- * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTag.java,v
1.2 2000/11/06 01:20:00 glenn Exp $
- * $Revision: 1.2 $
- * $Date: 2000/11/06 01:20:00 $
+ * $Header:
/home/cvs/jakarta-taglibs/datetime/src/org/apache/taglibs/datetime/TimeZonesTag.java,v
1.3 2001/07/07 20:42:31 glenn Exp $
+ * $Revision: 1.3 $
+ * $Date: 2001/07/07 20:42:31 $
*
* ====================================================================
*
@@ -68,14 +68,14 @@
import javax.servlet.jsp.tagext.*;
/**
* JSP Tag <b>timezones</b>, used to loop through all the TimeZone's
* so that ID's and Display Names can be accessed by using the standard
* JSP <jsp:getProperty> tag.
* <p>
* The script variable of name <b>id</b> is availble only within the
* body of the <b>timezones</b> tag.
* <p>
* Loops through all the timezones.
* <p>
* If the optional attribute <b>locale</b> is <b>true</b>, the Displaynames
* are formatted for the clients locale if known.
@@ -85,11 +85,11 @@
* <p>
* JSP Tag Lib Descriptor
* <p><pre>
- * <name>timezones</name>
+ * <name>timeZones</name>
* <tagclass>org.apache.taglibs.datetime.TimeZonesTag</tagclass>
* <teiclass>org.apache.taglibs.datetime.TimeZonesTEI</teiclass>
* <bodycontent>JSP</bodycontent>
- * <info>Loop through all the timezone display names.</info>
+ * <info>Loop through all the timeZone display names.</info>
* <attribute>
* <name>id</name>
* <sessuired>true</sessuired>
@@ -114,8 +114,8 @@
{
private Locale locale = null;
private int style = TimeZone.SHORT;
- private String [] timezones = null;
- private TimeZone timezone = null;
+ private String [] timeZones = null;
+ private TimeZone timeZone = null;
private int zone_num = 0;
/**
@@ -125,10 +125,10 @@
*/
public final int doStartTag() throws JspException
{
- timezones = TimeZone.getAvailableIDs();
+ timeZones = TimeZone.getAvailableIDs();
- timezone = TimeZone.getTimeZone(timezones[zone_num]);
- if( timezone == null )
+ timeZone = TimeZone.getTimeZone(timeZones[zone_num]);
+ if( timeZone == null )
return SKIP_BODY;
pageContext.setAttribute(id,this,PageContext.PAGE_SCOPE);
@@ -136,20 +136,20 @@
}
/**
* Method called at end of each timezones tag.
*
- * @return EVAL_BODY_TAG if there is another timezone, or SKIP_BODY if there
are no more timezones
+ * @return EVAL_BODY_TAG if there is another timeZone, or SKIP_BODY if there
are no more timeZones
*/
public final int doAfterBody() throws JspException
{
// See if we are done looping through timezones
zone_num++;
- if( zone_num >= timezones.length )
+ if( zone_num >= timeZones.length )
return SKIP_BODY;
- // There is another timezone, so loop again
- timezone = TimeZone.getTimeZone(timezones[zone_num]);
- if( timezone == null )
+ // There is another timeZone, so loop again
+ timeZone = TimeZone.getTimeZone(timeZones[zone_num]);
+ if( timeZone == null )
return SKIP_BODY;
return EVAL_BODY_TAG;
@@ -174,7 +174,7 @@
}
/**
- * Locale flag, if set to true, format timezone Displayname
+ * Locale flag, if set to true, format timeZone Displayname
* for client's preferred locale if known.
*
* @param String either <b>true</b> or <b>false</b>
@@ -197,7 +197,7 @@
}
/**
- * Returns the display name of the timezone.
+ * Returns the display name of the timeZone.
* <p>
* <jsp:getProperty name=<i>"id"</i> property="displayName"/>
*
@@ -209,13 +209,13 @@
Date now = new Date();
boolean daylight = false;
- if( timezone.useDaylightTime() )
- daylight = timezone.inDaylightTime(now);
+ if( timeZone.useDaylightTime() )
+ daylight = timeZone.inDaylightTime(now);
if( locale != null ) {
- dn = timezone.getDisplayName(daylight, style, locale);
+ dn = timeZone.getDisplayName(daylight, style, locale);
} else {
- dn = timezone.getDisplayName(daylight, style);
+ dn = timeZone.getDisplayName(daylight, style);
}
if( dn == null )
@@ -233,11 +233,11 @@
*/
public final String getZoneId()
{
- return timezone.getID();
+ return timeZone.getID();
}
/**
* Remove the script variable after timezones tag closed out
*/
public final void release()
{
@@ -68,14 +68,14 @@
import javax.servlet.jsp.tagext.*;
/**
- * JSP Tag <b>timezones</b>, used to loop through all the TimeZone's
+ * JSP Tag <b>timeZones</b>, used to loop through all the TimeZone's
* so that ID's and Display Names can be accessed by using the standard
* JSP <jsp:getProperty> tag.
@@ -68,14 +68,14 @@
* <p>
* The script variable of name <b>id</b> is availble only within the
- * body of the <b>timezones</b> tag.
+ * body of the <b>timeZones</b> tag.
* <p>
@@ -68,14 +68,14 @@
* <p>
- * Loops through all the timezones.
+ * Loops through all the timeZones.
* <p>
* If the optional attribute <b>locale</b> is <b>true</b>, the Displaynames
@@ -136,20 +136,20 @@
}
/**
- * Method called at end of each timezones tag.
+ * Method called at end of each timeZones tag.
*
@@ -136,20 +136,20 @@
public final int doAfterBody() throws JspException
{
- // See if we are done looping through timezones
+ // See if we are done looping through timeZones
zone_num++;
@@ -233,11 +233,11 @@
}
/**
- * Remove the script variable after timezones tag closed out
+ * Remove the script variable after timeZones tag closed out
*/
public final void release()